/**
 * SAUserPrefs plugin styles (tab styles)
 */

@import (reference) "../../../../skins/elastic/styles/fontawesome";

.listing.iconized li.sauserprefs > a::before {
  content: @fa-var-fire-alt;
}

// for Taskwatermark plugin
div.watermark.task-settings.action-plugin_sauserprefs::before {
  content: @fa-var-fire-alt;
}