<?php
/* Author: Joan Riera Pol */

$labels = [];
$labels['sauserprefs'] = 'Spam';
$labels['sauserprefssettings'] = 'Preferencias de Spam';
$labels['spamgeneralsettings'] = 'Preferencias Generales';
$labels['spamthres'] = 'Margen de puntuación';
$labels['spamsubject'] = 'Etiqueta del asunto';
$labels['spamsubjectblank'] = '(dejar en blanco para ninguna)';
$labels['spamlang'] = 'Idiomas de mensaje';
$labels['enabled'] = 'Habilitado';
$labels['disabled'] = 'Deshabilitado';
$labels['headers'] = 'Cabecera de mensajes';
$labels['foldheaders'] = 'Permitir múltiples líneas en cabecera';
$labels['spamlevelstars'] = 'Usar \'nivel de spam\' en cabecera';
$labels['spamlevelchar'] = 'Caracter para el nivel de spam';
$labels['spamtests'] = 'Pruebas de Spam basadas en Internet';
$labels['userazor1'] = 'Usar Razor v1';
$labels['userazor2'] = 'Usar Razor v2';
$labels['usepyzor'] = 'Usar Pyzor';
$labels['usebayes'] = 'Usar clasificador de estilo Bayesian';
$labels['usedcc'] = 'Usar DCC';
$labels['skiprblchecks'] = 'Usar lista negra en tiempo real';
$labels['spamreportsettings'] = 'Preferencias de informes';
$labels['spamreport0'] = 'Incluir informe en la cabecera del mensaje original';
$labels['spamreport1'] = 'Incluir original como adjunto MIME al informe';
$labels['spamreport2'] = 'Incluir al informe el original como adjunto de sólo texto';
$labels['spamaddressrules'] = 'Reglas de direcciones';
$labels['welcomelist_from'] = 'Aceptar correos de';
$labels['blocklist_from'] = 'Rechazar correos de';
$labels['welcomelist_to'] = 'Aceptar correos mandados a';
$labels['addrule'] = 'Añadir regla';
$labels['rule'] = 'Regla';
$labels['importfromaddressbook'] = 'Importar direcciones desde el la lista de contactos';
$labels['deleteall'] = 'Eliminar todos';
$labels['autoscore'] = 'Auto';
$labels['defaultscore'] = 'Puntuación por defecto';
$labels['otherscore'] = 'Otro (%s)';
$labels['saupusedefault'] = 'Restaurar preferencias por defecto';
$labels['langoptions'] = 'Opciones de idioma';
$labels['bayes'] = 'Preferencias Bayesianas';
$labels['purgingbayes'] = 'Eliminando datos Bayesianos...';
$labels['purgebayes'] = 'Eliminar datos personales Bayesianos';
$labels['bayesautolearn'] = 'Utilizar autoaprendizaje Bayes';
$labels['bayesautooptions'] = 'Opciones de autoaprendizaje';
$labels['bayesnonspam'] = 'Sin umbral de spam';
$labels['bayesspam'] = 'Umbral de Spam';
$labels['bayesrules'] = 'Usar reglas Bayesianas';
$labels['help'] = 'Ayuda';

$messages = [];
$messages['sauserprefchanged'] = 'Preferencias de spam modificadas';
$messages['sauserpreffailed'] = 'Error: No se han podido modificar las preferencias de spam';
$messages['spamthresexp'] = 'Cualquier correo por encima del umbral será marcado como spam. Ampliando este umbral se incrementará la cantidad de spam no filtrado, pero reducirá el riesgo de falsos positivos.';
$messages['spamlangexp'] = 'Selecciona los idiomas en los que esperas recibir los correos. Cualquier mensaje recibido escrito en cualquiera de los idiomas no seleccionados será tratado como posible spam.';
$messages['headersexp'] = 'SpamAssassin añade cabeceras a mensajes procesados proporcionando información sobre los resultados. Usar las opciones inferiores para configurar estas cabeceras.';
$messages['spamtestssexp'] = 'Algunas comprobaciones utilizan servicios en red para ayudar a identificar spam. Selecciona los que deseas utilizar:';
$messages['spamreport'] = 'Cuando un mensaje es identificado como spam se creará un reporte de las pruebas y las puntuaciones asignadas...';
$messages['autowelcomelist'] = 'Las cuentas de correo en tu lista de contactos son añadidas de forma automática a la lista \'Aceptar correos de\'.';
$messages['welcomelistexp'] = 'Un asterisco (*) puede ser utilizado como wildcard para mayor flexibilidad. Por ejemplo: *@ejemplo.com o *.ejemplo.com.';
$messages['spamaddressexists'] = 'Ya existe una regla para esta dirección';
$messages['spamenteraddress'] = 'Por favor, introduce una dirección a añadir';
$messages['spamaddresserror'] = 'Error: La dirección parece errónea';
$messages['spamaddressdelete'] = '¿Estás seguro de eliminar esta regla?';
$messages['spamaddressdeleteall'] = '¿Estás seguro de eliminar todas las reglas?';
$messages['noaddressrules'] = 'No se han encontrado reglas.';
$messages['importingaddresses'] = 'Importando direcciones...';
$messages['usedefaultconfirm'] = '¿Estás seguro de querer restaurar las preferencias por defecto? Esto eliminará todas tus preferencias, incluyendo tus reglas de direcciones.';
$messages['purgebayesexp'] = 'Eliminar datos Bayesianos personales recolectados de tu correo';
$messages['bayesnonspamexp'] = 'Mensajes con puntuación menor al umbral será utilizado para mejorar los sistemas de detección de correos que no son spam.';
$messages['bayesspamexp'] = 'Mensajes con puntuación superior al umbral serán utilizados para mejorar los sistemas de detección de correos no deseados.';
$messages['bayesautohelp'] = 'Cuando se activa el autoaprendizaje Bayesiano el sistema precesará automáticamente los mensajes que posiblemente sean spam/no spam y usará su información para mejorar los filtros de detección.';
$messages['bayeshelp'] = 'El clasificador Bayesiano trata de identificar spam buscando palabras o combinaciones cortas de letras que se encuentran comunmente en mensajes de spam.';
$messages['rblhelp'] = 'Los servidores encontrados en los enlaces en los correos recibidos serán comprobadas en varias \'listas negras\' o listas de fuentes de spam conocidas.';
$messages['dcchelp'] = 'El DCC o Distributed Checksum Clearinghouse es un sistema de servidores coleccionando y contando checksums (o firmas) de millones de correos electrónicos cada día. Cuanto más parecido es el checksum de un mensaje entrante a la lista es más probable que sea spam.';
$messages['pyzhelp'] = 'Pyzor es un sistema en red colaborativo para detectar y bloquear spam utilizando trozos de mensajes. Estos trozos son generados en varias formas distintas para buscar pequeñas diferencias en el contenido del mensaje.';
$messages['raz2help'] = 'Vipul\'s Razor es una red distribuida, colaborativa para la detección y filtrado de spam basada en envíos de usuarios. La detección es llevada a cabo con firmas que encuentran de forma eficiente el contenido spam. Los reportes de spam son validados mediante reputación dada a cada reportante.';
$messages['raz1help'] = 'Vipul\'s Razor es una red distribuida, colaborativa para la detección y filtrado de spam basada en envíos de usuarios. La detección es llevada a cabo con firmas que encuentran de forma eficiente el contenido spam. Los reportes de spam son validados mediante reputación dada a cada reportante. Versión 1 ha sido modificado ahora por version 2 y ya no es soportada.';
$messages['levelhelp'] = 'La cabecera de \'Nivel de Spam\' puede ser añadida a un mensaje para indicar la puntuación dada a un mensaje repitiendo determinadas veces el caracter especificado. Esto puede ser útil para el procesamiento posterior del mensaje.';
$messages['foldhelp'] = '¿Debe la cabecera añadida por SpamAssassin ser cortada? En otras palabras, ¿debe ser partida en varias líneas la cabecera en vez de una muy larga? Cuando una linea es partida está indicada para marcarla como la continuacióon de la siguiente.';
$messages['bayesruleshlp'] = 'Antes de que el clasificador de estilo Bayesiano pueda ser usado de forma efectiva tiene que ser "entrenado" para detectar correctamente los mensajes de spam/no spam. Deshabilitando las reglas Bayesianas permitirá continuar aprendiendo de forma automática y manual de correo entrante pero no será usado para filtrarlo.';
$messages['purgebayesconfirm'] = '¿Estás seguro de querer eliminar todos tus datos Bayesianos?';
