<?php
/* Author: David Garabana Barro */

$labels = [];
$labels['sauserprefs'] = 'Correo lixo';
$labels['sauserprefssettings'] = 'Axustes de correo lixo';
$labels['spamgeneralsettings'] = 'Axustes xerais';
$labels['spamthres'] = 'Umbral de puntuación';
$labels['spamsubject'] = 'Etiqueta do asunto';
$labels['spamsubjectblank'] = '(deixar en branco para ningún)';
$labels['spamlang'] = 'Idiomas da mensaxe';
$labels['enabled'] = 'Activado';
$labels['disabled'] = 'Desactivado';
$labels['headers'] = 'Cabeceiras da mensaxe';
$labels['foldheaders'] = 'Permitir cabecerias de máis dunha liña';
$labels['spamlevelstars'] = 'Utilizar a cabeceira \'Spam Level\'';
$labels['spamlevelchar'] = 'Caracter de nivel de correo lixo';
$labels['spamtests'] = 'Probas de correo lixo en Internet';
$labels['userazor1'] = 'Utilizar Razor v1';
$labels['userazor2'] = 'Utilizar Razor v2';
$labels['usepyzor'] = 'Utilizar Pyzor';
$labels['usebayes'] = 'Utilizar o clasificador de tipo Bayesian';
$labels['usedcc'] = 'Utilizar DCC';
$labels['skiprblchecks'] = 'Utilizar a \'Realtime Blackhole List\' (RBL)';
$labels['spamreportsettings'] = 'Axustes de informes ';
$labels['spamreport0'] = 'Incluir informe nas cabeceiras da mensaxe orixinal';
$labels['spamreport1'] = 'Incluir a mensaxe orixinal coma anexo MIME ao informe';
$labels['spamreport2'] = 'Incluir a mensaxe orixinal coma anexo de texto ao informe';
$labels['spamaddressrules'] = 'Regras de direccións';
$labels['welcomelist_from'] = 'Aceptar correo de';
$labels['blocklist_from'] = 'Rexeitar correo de';
$labels['welcomelist_to'] = 'Aceptar correo enviado a';
$labels['addrule'] = 'Engadir regra';
$labels['rule'] = 'Regra';
$labels['importfromaddressbook'] = 'Importar direccións dende a libreta de direccións';
$labels['deleteall'] = 'Eliminar todo';
$labels['autoscore'] = 'Auto';
$labels['defaultscore'] = 'Puntuación por omisión';
$labels['otherscore'] = 'Outro (%s)';
$labels['saupusedefault'] = 'Restaurar os valores por omisión';
$labels['langoptions'] = 'Opcións da linguaxe';
$labels['bayes'] = 'Axustes de Bayes';
$labels['purgingbayes'] = 'Eliminando os datos bayesianos';
$labels['purgebayes'] = 'Eliminando os datos persoais bayesianos';
$labels['bayesautolearn'] = 'Empregar autoaprendizaxe bayesiano';
$labels['bayesautooptions'] = 'Opcións de autoaprendizaxe';
$labels['bayesnonspam'] = 'Umbral de "non correo lixo"';
$labels['bayesspam'] = 'Umbral de "correo lixo"';
$labels['bayesrules'] = 'Empregar regras bayesianas';
$labels['help'] = 'Axuda';

$messages = [];
$messages['sauserprefchanged'] = 'Modificáronse correctamente os axustes de correo lixo';
$messages['sauserpreffailed'] = 'Produciuse un erro: Non se poden modificar os axustes de correo lixo';
$messages['spamthresexp'] = 'Calquera puntuación por enbira desde umbral é marcado coma correo lixo. Se sube este umbral, aumentará a cantidade de correo lixo non detectado, pero tamén reducirá o risco de que se produzan falsos positivos.';
$messages['spamlangexp'] = 'Escolla as linguaxes nas que espera recibir correo electrónico.Calquera mensaxe que reciba escrita nunha língua non seleccionada será tratada coma posible correo lixo.';
$messages['headersexp'] = 'SpamAssassin engade cabeceiras ás mensaxes procesadas informando dos resultados. Empregue as opcións de embaixo para configurar estas cabeceiras.';
$messages['spamtestssexp'] = 'Algunhas das probas utilizan servicios de Internet para axudar a identificar o correo lixo. Escolla as que lle gostaría empregar:';
$messages['spamreport'] = 'Cando unha mensaxe se identifica coma correo lixo, créase un informe de tódalas probas probas e puntuacións asignadas...';
$messages['autowelcomelist'] = 'As direccións de correo electrónico na súa libreta de direccións engádense automáticamente á lista de \'Aceptar correo de\'';
$messages['welcomelistexp'] = 'Pódese usar un asterisco (*) coma comodín para ter máis flexibilidade. Por exemplo: *@exemplo.com ou *.exemplo.com.';
$messages['spamaddressexists'] = 'Xa existe una regra para esta dirección';
$messages['spamenteraddress'] = 'Por favor, introduza unha dirección para engadir';
$messages['spamaddresserror'] = 'Produciuse un erro: A dirección semella inválida';
$messages['spamaddressdelete'] = 'Está seguro de que quere borrar esta regra?';
$messages['spamaddressdeleteall'] = 'Está seguro de que quere borrar tódalas regras de dirección?';
$messages['noaddressrules'] = 'Non se atoparon regras de dirección';
$messages['importingaddresses'] = 'Importando direccións...';
$messages['usedefaultconfirm'] = 'Está seguro de que quere restaurar os valores po omisión?. Esto vai borrar tódolos seus axustes, incluso as regras de dirección.';
$messages['purgebayesexp'] = 'Eliminar os datos bayesianos persoais do seu correo electrónico';
$messages['bayesnonspamexp'] = 'As mensaxes con puntuación menor a este umbrar vanse usar para mellorar os sistemas de detección de mensaxes non lixo';
$messages['bayesspamexp'] = 'As mensaxes con puntuación maior a este umbrar vanse usar para mellorar os sistemas de detección de mensaxes lixo';
$messages['bayesautohelp'] = 'Cando está activado o autoaprendizaxe bayesiano, o sistema vai procesar automáticamente as mensaxes que semellan correo lixo/non lixo, e usará a información destes para mellorar os filtros de detección.';
$messages['bayeshelp'] = 'O clasificador bayesiano tenta identificar o correo lixo buscando por verbas ou secuencias cortas de caracteres que adoitan atoparse en mensaxes lixo e non lixo.';
$messages['rblhelp'] = 'As direccións de servidores atopadas en ligazóns nunha mensaxe hanse comprobar en diversas "listas negras" ou listas de orixes coñecidos de correo lixo.';
$messages['dcchelp'] = 'O "Distributed Checksum Clearinghouse" é un sistema de servidores que colleitan e contan sumas de comprobación (ou sinaturas) de millóns de mensaxes de correo cada día. Canto máis se pareza una suma dunha mensaxe entrante a unha da lista, máis probable é que sea corre lixo.';
$messages['pyzhelp'] = 'Pyzor é un sistema colaborativo en rede para detectar e bloquear correo lixo utilizando resumos que identifican mensaxes. Os resumos xenéranse de varias maneiras distintas, para atopar pequenas diferencias no contido da mensaxe.';
$messages['raz2help'] = 'Vipul\'s Razor é unha rede distribuida e colaborativa de detección e filtrado de correo lixo, que se basa en envíos de correo lixo por parte de usuarios. A detección faise por medio de sinaturas que paran de manera eficiente a mutación dos contidos do correo lixo. Os envíos de correo lixo valídanse a través de asignacións de reputación que se lle otorga a cada usuario.';
$messages['raz1help'] = 'Vipul\'s Razor é unha rede distribuida e colaborativa de detección e filtrado de correo lixo, que se basa en envíos de correo lixo por parte de usuarios. A detección faise por medio de sinaturas que paran de manera eficiente a mutación dos contidos do correo lixo. Os envíos de correo lixo valídanse a través de asignacións de reputación que se lle otorga a cada usuario. A versión 1 foi trocada pola 2, e xa non está soportada.';
$messages['levelhelp'] = 'Pódese engadir a cabeceria "Spam Level" á mensaxe para indicar a puntuación dada repetindo o carácter especificad tantas veces coma puntos teña a mensaxe. Pode ser útil para procesamiento posterior da menxase.';
$messages['foldhelp'] = 'Deberíanse cortar as cabeceiras engadidas por SpamAssassin? Ou, dito doutro xeito, deberíanse dividir en varias liñas no canto de deixala nuna soa liña moi longa?. Cando se divide unha liña sángrase para indicar que é continuación da anterior.';
$messages['bayesruleshlp'] = 'Antes de poder usar o clasificador tipo bayesiano, é necesario "entranalo" para que detecte eficientemente correos lixo/non lixo. Se se desactivan as regras bayesianas, permítese que o sistema continue a aprender automáticamente e manualmente das mensaxes entrantes, pero non se vai usar para detectar correo lixo.';
$messages['purgebayesconfirm'] = 'Está seguro de que quere borrar os seus datos bayesianos?';
