<?php
/* Author: Alessio Cecchi */

$labels = [];
$labels['sauserprefs'] = 'Spam';
$labels['managespam'] = 'Gestisci le impostazioni di rilevamento dello Spam';
$labels['sauserprefssettings'] = 'Impostazioni spam';
$labels['spamgeneralsettings'] = 'Impostazioni generali';
$labels['spamthres'] = 'Punteggio valutazione';
$labels['spamsubject'] = 'Tag oggetto';
$labels['spamsubjectblank'] = '(lasciare in bianco se niente)';
$labels['spamlang'] = 'Lingue del messaggio';
$labels['enabled'] = 'Abilitato';
$labels['disabled'] = 'Disabilitato';
$labels['headers'] = 'Intestazioni messaggio';
$labels['foldheaders'] = 'Consenti più linee nell\'intestazione';
$labels['spamlevelstars'] = 'Usa instazione \'Spam Level\'';
$labels['spamlevelchar'] = 'carattere \'Spam level\'';
$labels['spamtests'] = 'Test spam su internet';
$labels['userazor1'] = 'Usa Razor v1';
$labels['userazor2'] = 'Usa Razor v2';
$labels['usepyzor'] = 'Usa Pyzor';
$labels['usebayes'] = 'Usa stile classificazione ingenua Bayesiana';
$labels['usedcc'] = 'Usa DCC';
$labels['skiprblchecks'] = 'Usa RBL (Realtime Blackhole List)';
$labels['spamreportsettings'] = 'Impostazioni dei rapporti';
$labels['spamreport0'] = 'Includi report nelle intestazioni del messaggio originale';
$labels['spamreport1'] = 'Includi il messaggio originale come allegato MIME al raporto';
$labels['spamreport2'] = 'Includi il messeggio originale come allegato TXT al rapporto';
$labels['spamaddressrules'] = 'Regole su indirizzi';
$labels['welcomelist_from'] = 'Consenti DA ( From: )';
$labels['blocklist_from'] = 'Nega DA ( From: )';
$labels['welcomelist_to'] = 'Consenti destinatiari ( To: )';
$labels['addrule'] = 'Aggiungi regola';
$labels['rule'] = 'Regola';
$labels['importfromaddressbook'] = 'Importa indirizzi dalla rubrica online';
$labels['deleteall'] = 'Cancella tutto';
$labels['autoscore'] = 'Automatico';
$labels['defaultscore'] = 'Punteggio standard';
$labels['otherscore'] = 'Altro (%s)';
$labels['saupusedefault'] = 'Ripristina le impostazioni iniziali';
$labels['langoptions'] = 'Opzioni Lingua';
$labels['bayes'] = 'Impostazione filtri Bayesiani';
$labels['purgingbayes'] = 'Cancellazione dei dati Bayesiani...';
$labels['purgebayes'] = 'Elimina i dati personali Bayesiani';
$labels['bayesautolearn'] = 'Utilizza l\'Apprendimento automatico Bayesiano';
$labels['bayesautooptions'] = 'Impostazioni Apprendimento automatico';
$labels['bayesnonspam'] = 'Soglia di Non Spam';
$labels['bayesspam'] = 'Soglia di Spam';
$labels['bayesrules'] = 'Utilizza i filtri Bayesiani';
$labels['help'] = 'Aiuto';

$messages = [];
$messages['sauserprefchanged'] = 'Cambiamenti applicati con successo';
$messages['sauserpreffailed'] = 'Errore: imposibile salvare i cambiamenti';
$messages['spamthresexp'] = 'Tutto quello che oltre passa il punteggio verrà segnalato come spam. Aumentare il punteggio significa aumentare i messaggi di spam non segnalati, ma riduce il richio di falsi positivi.';
$messages['spamlangexp'] = 'Selezionare tutte le lingue in cui ci si aspetta possa arrivare un messaggio. Tutti i messaggi che arriveranno in una lingua non selezionata saranno segnalati come spam.';
$messages['headersexp'] = 'SpamAssassin aggiunge delle intestazioni al messaggioriguardante il risultato dell\'analisi. Usare questa opzione per configurare queste intestazioni.';
$messages['spamtestssexp'] = 'Certi controlli utilizzano dei servizi internet per analizzare il messaggio. Selezionare quello che si vuole utilizzare:';
$messages['spamreport'] = 'Quando un messaggio viene identificato come spam viene creato un rapporto dei test ed il punteggio questo rapporto viene creato...';
$messages['autowelcomelist'] = 'Gli indirizzi Email della Rubrica della Webmail vengono caricati automaticamente ed inseriti nella lista \'Consenti mail DA\'.';
$messages['welcomelistexp'] = 'Un asterisco (*) può essere usato come carattere \'jolly\' per aumentare la flessibilità della regola. Ad esempio: *@dominio.com o *.dominio.com.';
$messages['spamaddressexists'] = 'Esiste già una regola per questo indirizzo';
$messages['spamenteraddress'] = 'Inserire un indirizzo da aggiungere';
$messages['spamaddresserror'] = 'Errore: Indirizzo invalido';
$messages['spamaddressdelete'] = 'Sicuro di voler CANCELLARE questa regola?';
$messages['spamaddressdeleteall'] = 'Sicuro di voler CANCELLARE TUTTI gli indirizzi della lista??';
$messages['noaddressrules'] = 'Nessuna regola trovata.';
$messages['importingaddresses'] = 'Importazione indirizzi...';
$messages['usedefaultconfirm'] = 'Sicuro di voler ripristinare le impostazioni iniziali ? Questa operazione CANCELLERA TUTTE LE IMPOSTAZIONI, incluse le regole per i messaggi!.';
$messages['purgebayesexp'] = 'Elimina i dati Bayesiani personali raccolti dal tuo indirizzo email';
$messages['bayesnonspamexp'] = 'I messaggi con punteggio al di sotto di questa soglia verranno utilizzati per migliorare l\'individuazione dei messaggi non spam.';
$messages['bayesspamexp'] = 'I messaggi con punteggio al di sopra di questa soglia verranno utilizzati per migliorare l\'individuazione dei messaggi di spam.';
$messages['bayesautohelp'] = 'Quando l\'apprendimento automatico Bayesiano è abilitato il sistema analizza automaticamente i messaggi che con molta probabilità sono spam oppure no e utilizza le informazioni ricavate per migliorare il rilevamento.';
$messages['bayeshelp'] = 'I filtri Bayesiaio provano ad identificare lo spam, cercando parole o brevi sequenze di caratteri che si trovano più di frequente nei messaggi di spam e non.';
$messages['rblhelp'] = 'Gli indirizzi trovati nei collegamenti ipertestuali di un messaggio verranno controllati sulla base di diverse "liste nere" o liste di fonti di spam note.';
$messages['dcchelp'] = 'DCC o Distributed Checksum Clearinghouse è un sistema centralizzato di raccolta e conteggio checksum (o firme) di milioni di messaggi di posta elettronica in transito ogni giorno. Quanto maggiore è la somiglianza del checksum di un messaggio in arrivo nel sistema DCC, più probabile è che quel messaggio possa essere spam.';
$messages['pyzhelp'] = 'Pyzor è una network collaborativo per rilevare e bloccare lo spam utilizzando la raccolta ed il conteggio dei digest (o firme) dei messaggi. I digest sono generati in un numero di modi diversi per tollerare piccole differenze nel contenuto del messaggio.';
$messages['raz2help'] = 'Vipul Razor è un network collaborativo per l\'individuazione dello spam. La rilevazione viene effettuata con le firme in modo efficiente al fine di individuare mutazione nei di spam. Le segnalazioni di spam sono convalidati mediante l\'assegnazione di reputazione dato a ogni contributore al network.';
$messages['raz1help'] = 'Vipul Razor è un network collaborativo per l\'individuazione dello spam. La rilevazione viene effettuata con le firme in modo efficiente al fine di individuare mutazione nei di spam. Le segnalazioni di spam sono convalidati mediante l\'assegnazione di reputazione dato a ogni contributore al network. La versione 1 è stata sostituita dalla versione 2 e non è più utilizzata.';
$messages['levelhelp'] = 'L\'intestazione \'Spam Level\' può essere aggiunto a un messaggio per indicare il punteggio assegnatoli ripetendo il carattere specificato molte volte. Ciò può essere utile per un ulteriore elaborazione del messaggio.';
$messages['foldhelp'] = 'Gli header aggiunti da SpamAssassin devono essere suddivisi? In altre parole, essi dovrebbero essere suddivisi in più righe invece di una molto lunga. Quando una linea è interrotta apparirà rientrata per segnalare la continuazione della precedente.';
$messages['bayesruleshlp'] = 'Prima che i filtri Bayesiani possano funzionare in modo efficace devono essere "addestrati" per rilevare correttamente i messaggi di spam e non. La disattivazione delle regole bayesiane permette al sistema di continuare l\'apprendimento sia automaticamente che manualmente sulla posta in arrivo, ma non saranno utilizzati per rilevare lo spam.';
$messages['purgebayesconfirm'] = 'Sei sicuro di voler eliminare tutti i dati bayesiani?';
