<?php
/* Author: Ovidiu Bica */

$labels = [];
$labels['sauserprefs'] = 'Spam';
$labels['sauserprefssettings'] = 'Setari spam';
$labels['spamgeneralsettings'] = 'Setari generale';
$labels['spamthres'] = 'Scor maxim';
$labels['spamsubject'] = 'Cuvant cheie, ex. [SPAM]';
$labels['spamsubjectblank'] = '(lasati gol pentru niciunul)';
$labels['spamlang'] = 'Mesaje in limbile';
$labels['enabled'] = 'Activat';
$labels['disabled'] = 'Dezactivat';
$labels['headers'] = 'Header mesaje';
$labels['foldheaders'] = 'Permite linii multiple in header';
$labels['spamlevelstars'] = 'Foloseste \'Nivel de spam\' in header';
$labels['spamlevelchar'] = 'Caracter pentru nivel spam';
$labels['spamtests'] = 'Teste spam de pe internet.';
$labels['userazor1'] = 'Foloseste Razor v1';
$labels['userazor2'] = 'Foloseste Razorv2';
$labels['usepyzor'] = 'Foloseste Pyzor';
$labels['usebayes'] = 'Foloseste stilul de clasificare Bayesian';
$labels['usedcc'] = 'Foloseste DCC';
$labels['skiprblchecks'] = 'Foloseste lista Blackhole in timp real';
$labels['spamreportsettings'] = 'Setari raportari';
$labels['spamreport0'] = 'Include raportul in headerul mesajului original';
$labels['spamreport1'] = 'Include raportul original ca atasament MIME';
$labels['spamreport2'] = 'Include raportul original ca atasament text';
$labels['spamaddressrules'] = 'Reguli adrese';
$labels['welcomelist_from'] = 'Accepta mail de la';
$labels['blocklist_from'] = 'Refuza mail de la';
$labels['welcomelist_to'] = 'Accepta mail trimis la';
$labels['addrule'] = 'Adauga regula';
$labels['rule'] = 'Regula';
$labels['importfromaddressbook'] = 'Importa adresele din agenda';
$labels['deleteall'] = 'Sterge tot';
$labels['autoscore'] = 'Automat';
$labels['defaultscore'] = 'Scor implicit';
$labels['otherscore'] = 'Altele (%s)';
$labels['saupusedefault'] = 'Restaureaza setarile implicite';
$labels['langoptions'] = 'Optiuni lingvistice';
$labels['bayes'] = 'Setari Bayes';
$labels['purgingbayes'] = 'Sterg datele Bayesian';
$labels['purgebayes'] = 'Sterg datele Bayesian personale';
$labels['bayesautolearn'] = 'Foloseste instruirea automata a filtrului Bayes';
$labels['bayesautooptions'] = 'Optiuni instruire automata';
$labels['bayesnonspam'] = 'Prag limita non spam';
$labels['bayesspam'] = 'Prag limita spam';
$labels['bayesrules'] = 'Foloseste reguli Bayesian';
$labels['help'] = 'Ajutor';

$messages = [];
$messages['sauserprefchanged'] = 'Setarile de SPAM au fost setate cu succes.';
$messages['sauserpreffailed'] = 'Eroare: Nu pot actualiza setarile de spam.';
$messages['spamthresexp'] = 'Orice mesaj mai mare de acest prag va fi marcat ca spam. Crescand acest prag va mari numarul de mesaje spam nedetectate insa va reduce numarul de mesaje interpretate gresit ca spam.';
$messages['spamlangexp'] = 'Selecteaza toate limbile in care te astepti sa primesti mesaje. Orice mesaj receptionat intr-o alta limba va fi considerat spam.';
$messages['headersexp'] = 'Spamassassin adauga headere la mesajele procesate furnizand informatii despre rezultate. Foloseste optiunile de mai jos pentru a configura aceste headere.';
$messages['spamtestssexp'] = 'Unele verificari folosesc servicii de pe internet in vederea detectarii spamului. Selecteaza-le pe cele pe care doresti sa le folosesti.';
$messages['spamreport'] = 'Cand un mesaj este identificat ca spam, este creat un raport al testelor si al scorurilor. ';
$messages['autowelcomelist'] = 'Adresele de email din agenda sunt adaugate automat in lista adreselor acceptate automat.';
$messages['welcomelistexp'] = 'O steluta (*) poate fi folosita ca inlocuitor global pentru o flexibilitate marita. De ex. *@exemplu.com sau *.exemplu.com';
$messages['spamaddressexists'] = 'Exista deja o regula pentru aceasta adresa.';
$messages['spamenteraddress'] = 'Te rog sa introduci o adresa pentru a o adauga.';
$messages['spamaddresserror'] = 'Eroare: Adresa pare invalida.';
$messages['spamaddressdelete'] = 'Esti sigur ca doresti sa stergi aceasta regula?';
$messages['spamaddressdeleteall'] = 'Esti sigur ca doresti sa stergi toate regulile?';
$messages['noaddressrules'] = 'Nu a fost gasita nici o regula.';
$messages['importingaddresses'] = 'Import adresele ....';
$messages['usedefaultconfirm'] = 'Esti sigur ca doresti sa revi la setarile initiale? Aceasta actiune va sterge toate setarile efectuate pana in prezent .';
$messages['purgebayesexp'] = 'Sterge datele personale ale filtrului Bayesyan colectate de pe adresa ta.';
$messages['bayesnonspamexp'] = 'mesajele care au un scor sub acest prag vor fi folosite pentru antrenarea filtrului non spam';
$messages['bayesspamexp'] = 'Mesajele care au un scor peste acest prag vor fi folosite pentru detectarea mesajelor spam.';
$messages['bayesautohelp'] = 'Atunci cand este activat filtrul Bayesian autodidact, acesta proceseaza automat mesajele care sunt foarte probabil spam/non spam si foloseste aceste informatii pentru a imbunatati filtrele de detectie.';
$messages['bayeshelp'] = 'Filtrul Bayesian clasificator incearca sa identifice spam-ul uitandu-se la cuvinte sau secvente de caractere care sunt folosite frecvent in spam sau non spam.';
$messages['rblhelp'] = 'Adresele web gasite in legaturile din mesaje vor fi verificate in cateva liste negre sau liste cu spamer cunoscuti deja.';
$messages['dcchelp'] = 'The DCC or Distributed Checksum Clearinghouse is a system of servers collecting and counting checksums (or signatures) of millions of mail messages every day. The greater the similarity the checksum of an incoming message has to the list the more likely it is to be spam.';
$messages['pyzhelp'] = 'Pyzor is a collaborative, networked system to detect and block spam using identifying digests of messages. The digests are generated in a number of different ways to allow for small differences in the content of the message.';
$messages['raz2help'] = 'Vipul\'s Razor is a distributed, collaborative, spam detection and filtering network based on user submissions of spam. Detection is done with signatures that efficiently spot mutating spam content. The spam reports are validated through reputation assignments given to each reporter.';
$messages['raz1help'] = 'ipul\'s Razor is a distributed, collaborative, spam detection and filtering network based on user submissions of spam. Detection is done with signatures that efficiently spot mutating spam content. The spam reports are validated through reputation assignments given to each reporter. Version 1 has now been replaced by version 2 and is no longer supported.';
$messages['levelhelp'] = 'The \'Spam Level\' header can be added to a message to indicate the score given to a message by repeating the character specified that many times. This may be useful for further processing of the message.';
$messages['foldhelp'] = 'Should headers added by SpamAssassin will be wrapped? In other words, should they be broken up into multiple lines instead of one very long one. When a line is broken it will be indented to mark it as a continuation of the preceding one.';
$messages['bayesruleshlp'] = 'Before the Bayesian-style classifier can be used effectively it must be "trained" to properly detect spam/non spam messages. Disabling the Bayesian rules allows the system to continue to learn both automatically and manually from incoming mail but it will not be used to detect spam.';
$messages['purgebayesconfirm'] = 'Esti sigur ca doresti sa stergi toate datele Bayesiane?';
